from __future__ import absolute_import, unicode_literals

from django.db import models

from wagtail.wagtailcore.models import Page
from wagtail.wagtailcore.fields import RichTextField


class HomePage(Page):
    pass


class BlogPage(Page):
    intro = RichTextField()
    body = RichTextField()
    date = models.DateField("Post date")

    feed_image = models.ForeignKey(
        'wagtailimages.Image',
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name='+'
    )
